==> leopardo-0.0.3.tar.gz: leopardo-0.0.3/README.md <==
<h1 align="center">
  <img src="https://user-images.githubusercontent.com/50381946/167810957-14b78013-00cf-436e-b535-d2b89f881c44.png">
  <br>
  <code>
    leopardo
  </code>
  <br>
</h1>

Proin lacinia metus auctor est posuere, in ornare dui hendrerit. Aliquam eget est gravida, iaculis tortor a, aliquam ligula.

Morbi semper metus at egestas vulputate:

- Nullam viverra nisi vel tellus finibus tincidunt.
- Pellentesque at velit placerat, gravida eros eu, blandit est.
- Curabitur id odio et magna semper vestibulum.
- Donec id lectus ut mi tincidunt commodo et eget risus.


## Motivation

<div align="center">

![image](https://user-images.githubusercontent.com/50381946/190855236-6804df02-7f64-46a7-890a-9e0b60df7969.png)

</div>

## Installation

    pip install leopardo

Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium, totam rem aperiam, eaque ipsa quae ab illo inventore veritatis et quasi architecto beatae vitae dicta sunt explicabo. 

Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt. Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem.

Ut enim ad minima veniam, quis nostrum exercitationem ullam corporis suscipit laboriosam, nisi ut aliquid ex ea commodi consequatur? Quis autem vel eum iure reprehenderit qui in ea voluptate velit esse quam nihil molestiae consequatur, vel illum qui dolorem eum fugiat quo voluptas nulla pariatur?

## Usage

    grep -lrEe 'leopardo' | xargs sed 's/\leopardo/xxx/g'
    mv PROJECT_NAME xxx

At vero eos et accusamus et iusto odio dignissimos ducimus qui blanditiis praesentium voluptatum deleniti atque corrupti quos dolores et quas molestias excepturi sint occaecati cupiditate non provident, similique sunt in culpa qui officia deserunt mollitia animi, id est laborum et dolorum fuga. 

Et harum quidem rerum facilis est et expedita distinctio.

    grep --color -rEe '[*]PROJECT_\B'

Nam libero tempore, cum soluta nobis est eligendi optio cumque nihil impedit quo minus id quod maxime placeat facere possimus, omnis voluptas assumenda est, omnis dolor repellendus. Temporibus autem quibusdam et aut officiis debitis aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae sint et molestiae non recusandae. 

_Itaque earum rerum hic tenetur a sapiente delectus, ut aut reiciendis voluptatibus maiores alias consequatur aut perferendis doloribus asperiores repellat._

## Changelog

### v0.0.0

- yes

==> leopardo-0.0.4.tar.gz: leopardo-0.0.4/README.md <==
<h1 align="center">
  <img src="https://user-images.githubusercontent.com/50381946/167810957-14b78013-00cf-436e-b535-d2b89f881c44.png">
  <br>
  <code>
    leopardo
  </code>
  <br>
</h1>

Proin lacinia metus auctor est posuere, in ornare dui hendrerit. Aliquam eget est gravida, iaculis tortor a, aliquam ligula.

Morbi semper metus at egestas vulputate:

- Nullam viverra nisi vel tellus finibus tincidunt.
- Pellentesque at velit placerat, gravida eros eu, blandit est.
- Curabitur id odio et magna semper vestibulum.
- Donec id lectus ut mi tincidunt commodo et eget risus.


## Motivation

<div align="center">

![image](https://user-images.githubusercontent.com/50381946/190855236-6804df02-7f64-46a7-890a-9e0b60df7969.png)

</div>

## Installation

    pipx install leopardo

Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium, totam rem aperiam, eaque ipsa quae ab illo inventore veritatis et quasi architecto beatae vitae dicta sunt explicabo. 

Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt. Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem.

Ut enim ad minima veniam, quis nostrum exercitationem ullam corporis suscipit laboriosam, nisi ut aliquid ex ea commodi consequatur? Quis autem vel eum iure reprehenderit qui in ea voluptate velit esse quam nihil molestiae consequatur, vel illum qui dolorem eum fugiat quo voluptas nulla pariatur?

## Usage

    grep -lrEe 'leopardo' | xargs sed 's/\leopardo/xxx/g'
    mv PROJECT_NAME xxx

At vero eos et accusamus et iusto odio dignissimos ducimus qui blanditiis praesentium voluptatum deleniti atque corrupti quos dolores et quas molestias excepturi sint occaecati cupiditate non provident, similique sunt in culpa qui officia deserunt mollitia animi, id est laborum et dolorum fuga. 

Et harum quidem rerum facilis est et expedita distinctio.

    grep --color -rEe '[*]PROJECT_\B'

Nam libero tempore, cum soluta nobis est eligendi optio cumque nihil impedit quo minus id quod maxime placeat facere possimus, omnis voluptas assumenda est, omnis dolor repellendus. Temporibus autem quibusdam et aut officiis debitis aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae sint et molestiae non recusandae. 

_Itaque earum rerum hic tenetur a sapiente delectus, ut aut reiciendis voluptatibus maiores alias consequatur aut perferendis doloribus asperiores repellat._

## Changelog

### v0.0.0

- yes
